@@ -70,7 +70,12 @@ KPluginMetaData::KPluginMetaData(const QString &file)
             qCWarning(KCOREADDONS_DEBUG) << "Couldn't open" << file;
             return;
         }
-        m_metaData = QJsonDocument::fromJson(f.readAll()).object();
+
+        QJsonParseError error;
+        m_metaData = QJsonDocument::fromJson(f.readAll(), &error).object();
+        if (error.error) {
+            qCWarning(KCOREADDONS_DEBUG) << "error parsing" << file << error.errorString();
+        }
         m_fileName = file;
         d->metaDataFileName = file;
     } else {
@@ -174,6 +179,9 @@ QStringList KPluginMetaData::readStringList(const QJsonObject &obj, const QStrin
         return value.toVariant().toStringList();
     } else {
         QString asString = value.isString() ? value.toString() : value.toVariant().toString();
+        if (asString.isEmpty()) {
+            return QStringList();
+        }
         const QString id = obj.value(QStringLiteral("KPlugin")).toObject().value(QStringLiteral("Id")).toString();
         qCWarning(KCOREADDONS_DEBUG) << "Expected JSON property" << key << "to be a string list."
             " Treating it as a list with a single entry:" << asString << id.toLatin1().constData();
@@ -222,7 +230,8 @@ static QList<KAboutPerson> aboutPersonFromJSON(const QJsonValue &people)
         // single author
         addPersonFromJson(people.toObject(), &ret);
     } else if (people.isArray()) {
-        foreach (const QJsonValue &val, people.toArray()) {
+        const QJsonArray peopleArray =  people.toArray();
+        for (const QJsonValue &val : peopleArray) {
             if (val.isObject()) {
                 addPersonFromJson(val.toObject(), &ret);
             }
@@ -341,7 +350,23 @@ bool KPluginMetaData::isEnabledByDefault() const
 
 QString KPluginMetaData::value(const QString &key, const QString &defaultValue) const
 {
-    return m_metaData.value(key).toString(defaultValue);
+    const QJsonValue value = m_metaData.value(key);
+    if (value.isString()) {
+        return value.toString(defaultValue);
+    } else if (value.isArray()) {
+        qCWarning(KCOREADDONS_DEBUG) << "Expected JSON property" << key << "to be a single string."
+            " but it is a stringlist";
+        const QStringList list = value.toVariant().toStringList();
+        if (list.isEmpty()) {
+            return defaultValue;
+        }
+        return list.join(QChar::fromLatin1(','));
+    } else if (value.isBool()) {
+        qCWarning(KCOREADDONS_DEBUG) << "Expected JSON property" << key << "to be a single string."
+            " but it is a bool";
+        return value.toBool() ? QStringLiteral("true") : QStringLiteral("false");
+    }
+    return defaultValue;
 }
 
 bool KPluginMetaData::operator==(const KPluginMetaData &other) const
